package frc.robot.subsystems;

import com.revrobotics.CANSparkMax;

import java.util.function.DoubleSupplier;

import com.revrobotics.CANSparkBase.IdleMode;
import com.revrobotics.CANSparkLowLevel.MotorType;

import edu.wpi.first.wpilibj.DigitalInput;
import edu.wpi.first.wpilibj2.command.Command;
import edu.wpi.first.wpilibj2.command.SubsystemBase;
import frc.robot.constants.IndexerConstants;

public class Indexer extends SubsystemBase{
    private CANSparkMax indexerMotor;

    private DigitalInput indexerBeamBreak;

    private boolean autoIndex;

    public Indexer(){
        indexerMotor = new CANSparkMax(IndexerConstants.kMotorCANID, MotorType.kBrushed);

        indexerMotor.setSmartCurrentLimit(IndexerConstants.kMotorCurrentLimit);
        indexerMotor.setIdleMode(IdleMode.kBrake);
        indexerMotor.burnFlash();

        indexerBeamBreak = new DigitalInput(IndexerConstants.kBeamBreakChannel);

        autoIndex = false;
    }

    @Override
    public void periodic() {
        if(autoIndex) {
            if(!indexerBeamBreak.get()) {
                indexerMotor.set(.75);
            } else {
                indexerMotor.set(0);
            }
        }
    }

    public boolean getBeamBreak(){
        return indexerBeamBreak.get();
    }

    public Command autoIndex() {
        return runOnce(() -> {
            this.autoIndex = true;
        });
    }
    
    public Command setSpeed(DoubleSupplier speed){
        return runOnce(() -> { autoIndex = false; }).andThen(run(() -> {
            indexerMotor.set(speed.getAsDouble());
        }));
    }

    public Command stop() {
        return setSpeed(() -> 0);
    }
}
