package frc.robot.subsystems;

import java.util.function.DoubleSupplier;

import com.revrobotics.CANSparkMax;
import com.revrobotics.CANSparkBase.IdleMode;
import com.revrobotics.CANSparkLowLevel.MotorType;

import edu.wpi.first.wpilibj.DigitalInput;
import edu.wpi.first.wpilibj2.command.Command;
import edu.wpi.first.wpilibj2.command.SubsystemBase;
import frc.robot.constants.ShooterConstants;

public class Shooter extends SubsystemBase {
    private CANSparkMax topShooter;
    private CANSparkMax bottomShooter;

    private DigitalInput shooterBeamBreak;

    public Shooter(){
        topShooter = new CANSparkMax(ShooterConstants.kTopMotorCANID, MotorType.kBrushless);
        topShooter.setInverted(true);

        bottomShooter = new CANSparkMax(ShooterConstants.kBottomMotorCANID, MotorType.kBrushless);
        bottomShooter.setInverted(true);
        
        topShooter.setSmartCurrentLimit(ShooterConstants.kMotorCurrentLimit);
        bottomShooter.setSmartCurrentLimit(ShooterConstants.kMotorCurrentLimit);

        shooterBeamBreak = new DigitalInput(ShooterConstants.kBeamBreakChannel);

        topShooter.setIdleMode(IdleMode.kCoast);
        bottomShooter.setIdleMode(IdleMode.kCoast);

        topShooter.burnFlash();
        bottomShooter.burnFlash();
    }
 
    public boolean getBeamBreak(){
        return shooterBeamBreak.get();
    }

    public Command setSpeed(DoubleSupplier speed) {
        return run(() -> {
            topShooter.set(speed.getAsDouble());
            bottomShooter.set(speed.getAsDouble());
        });
    }

    public Command stop() {
        return setSpeed(() -> 0);
    }
}
